@@ -2,7 +2,7 @@ package Net::WebSocket::Frame::ping;
 
 =encoding utf-8
 
-=HEAD1
+=head1
 
 Net::WebSocket::Frame:ping:
 
@@ -13,7 +13,7 @@ Net::WebSocket::Frame:ping:
         #Optional, can be either empty (default) or four random bytes
         mask => q<>,
 
-        payload_sr => \$payload,
+        payload => $payload,
     );
 
     $frm->get_type();           #"ping"
@@ -40,10 +40,4 @@ use parent qw(
 
 use constant get_opcode => 9;
 
-sub new {
-    my ($class, @opts) = @_;
-
-    return $class->SUPER::new( @opts, type => 'ping' );
-}
-
 1;
